gdm r5937 - in branches/gnome-2-20: . gui
- From: bcameron svn gnome org
- To: svn-commits-list gnome org
- Subject: gdm r5937 - in branches/gnome-2-20: . gui
- Date: Thu, 6 Mar 2008 02:37:43 +0000 (GMT)
Author: bcameron
Date: Thu Mar 6 02:37:43 2008
New Revision: 5937
URL: http://svn.gnome.org/viewvc/gdm?rev=5937&view=rev
Log:
2008-03-05 Brian Cameron <brian cameron sun com>
* gui/gdmcommon.c: If the user uses the default remote welcome string
for local displays or vice-versa, then translate the string.
* gui/gdmflexiserver.c: Need to call gdk_init when running in
--command mode or the -a option fails when trying to call the
gdk function to get the display.
Modified:
branches/gnome-2-20/ChangeLog
branches/gnome-2-20/gui/gdmcommon.c
branches/gnome-2-20/gui/gdmflexiserver.c
Modified: branches/gnome-2-20/gui/gdmcommon.c
==============================================================================
--- branches/gnome-2-20/gui/gdmflexiserver.c (original)
+++ branches/gnome-2-20/gui/gdmflexiserver.c Thu Mar 6 02:37:43 2008
@@ -796,6 +796,9 @@
g_type_init ();
if (send_command != NULL) {
+
+ /* gdk_init is needed for cookie code to get display */
+ gdk_init (&argc, &argv);
if (authenticate)
auth_cookie = gdmcomm_get_auth_cookie ();
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- branches/gnome-2-20/gui/gdmcommon.c (original)
+++ branches/gnome-2-20/gui/gdmcommon.c Thu Mar 6 02:37:43 2008
@@ -618,8 +618,10 @@
gchar *tempstr;
/*
* Translate the welcome msg in the client program since it is running as the
* user and therefore has the appropriate language environment set.
*/
if (ve_string_empty (g_getenv ("GDM_IS_LOCAL"))) {
if (gdm_config_get_bool (GDM_KEY_DEFAULT_REMOTE_WELCOME))
@@ -630,6 +632,8 @@
if (tempstr == NULL ||
strcmp (ve_sure_string (tempstr), GDM_DEFAULT_REMOTE_WELCOME_MSG) == 0)
welcomemsg = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
+ else if (strcmp (ve_sure_string (tempstr), GDM_DEFAULT_WELCOME_MSG) == 0)
+ welcomemsg = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
else
welcomemsg = g_strdup (tempstr);
}
@@ -642,8 +646,10 @@
if (tempstr == NULL ||
strcmp (ve_sure_string (tempstr), GDM_DEFAULT_WELCOME_MSG) == 0)
welcomemsg = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
+ else if (strcmp (ve_sure_string (tempstr), GDM_DEFAULT_REMOTE_WELCOME_MSG) == 0)
+ welcomemsg = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
else
- welcomemsg = g_strdup (tempstr);
+ welcomemsg = g_strdup (tempstr);
}
}
Modified: branches/gnome-2-20/gui/gdmflexiserver.c
@@ -618,8 +618,10 @@
gchar *tempstr;
/*
- * Translate the welcome msg in the client program since it is running as the
- * user and therefore has the appropriate language environment set.
+ * Translate the welcome msg in the client program since it is running
+ * as the user and therefore has the appropriate language environment
+ * set. If the user wants to use the default remote welcome msg as the
+ * local welcome msg (or vice versa), then also translate.
*/
if (ve_string_empty (g_getenv ("GDM_IS_LOCAL"))) {
==============================================================================